%% Experimental cardiovascular data for validation 
% This script represents the experimental data of the cardiovascular system of a pig. 
%
% Cristina Nuevo-Gallardo   | cnuevog@unex.es   - October 2021
% José Emilio Traver        | jetraverb@unex.es - October 2021

%% Experimental data information

% Sampling Time 4 ms
%Ts_exp = 4e-3;

% Mean heart rate: 68
%Test x1 and x2: 68
%Test x3 and x4: 70
%Test x3 and x6: 67

% Cardiac output was calculated by the temperature difference between the 
% cold serum injected and the temperature recovery time.
% Test 1: 2.96 l/min
% Test 2: 3.20 l/min
% Test 3: 3.13 l/min
% Test 4: 3.45 l/min

%% Load data
clearvars
ts = 0:4e-3:4.4118;
load('./ExperimentalData/ExperimentalData_FractalFractional.mat')


%% Plot data
figure(1)
plot(ts,x2,'--o','linewidth',2)
hold on
plot(ts,x1,'linewidth',2)
plot(ts,x4,':','linewidth',2)
plot(ts,x3,'-.','linewidth',2)
plot(ts,x6,'--','linewidth',2)
hold off
grid
ylim([0 100])
xlim([0 4.4118])
ylabel('Pressure (mmHg)','Interpreter','latex','FontSize',28);
xlabel('Time (s)','Interpreter','latex','FontSize',28);
title('Experimental hemodynamic waveforms for a pig heart','Interpreter','latex','FontSize',28)
set(gca,'linewidth',2,'fontsize',28); 
legend('Left Atrial','Left ventricle','Descending aorta','Ascending aorta','Left common carotid'...
    ,'Interpreter','latex','FontSize',28,'fontweight','bold','Orientation','Horizontal')


%% Hemodynamic parameters (experimental data)
HR = 68;     % Heart rate
SP = 82;     % Systolic Pressure
DP = 62;     % Diastolic Pressure
MAP = DP + (SP - DP)/3; % Mean arterial pressure
CO = mean([2.96 3.20 3.13 3.45]); % Cardiac output
SV = CO/HR*1e3  % Stroke volume


